@@ -13,5 +13,5 @@ library(kableExtra)
 knitr::kable(head(iris,10), align = "c",format = 'html') %>%
   kableExtra::footnote(
     general_title = "Source: ",
-    general = as.character(whereami(path_expand = TRUE)))
+    general = whereami(path_expand = TRUE))
 
