@@ -5,10 +5,12 @@ testthat::describe("console functionality", {
   rstudioapi::sendToConsole("x <- whereami()")
 
   it("class", {
-    testthat::expect_true(inherits(x, "whereami"))
+    testthat::expect_true(inherits(x, c("whereami","character")))
   })
 
   it("value", {
     testthat::expect_equal(basename(x[1]), "Console")
   })
+
+  rstudioapi::sendToConsole("cat('\f')")
 })
